/*******************************************************************************
 * Copyright (c) 2003, 2007 s IT Solutions AT Spardat GmbH .
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     s IT Solutions AT Spardat GmbH - initial API and implementation
 *******************************************************************************/

// @(#) $Id: IListDomWMClient.java 2089 2007-11-28 13:56:13Z s3460 $
package at.spardat.xma.mdl.list;

import at.spardat.xma.mdl.IWModelClient;

/**
 * The client side API of an <tt>IListDomWM</tt>. Compared
 * to its super interface, this interface has some more
 * attributes that influence the visual contents of the combo box. 
 * Roughly, the combo may either display just long values, or a 
 * concatination of short and long values. Sort order may also be influenced. 
 * The values of these attributes are set in the UI designer/generator's
 * generated code and may be just queried here.
 * 
 * @author YSD, 20.04.2003 19:15:19
 */
public interface IListDomWMClient extends IListDomWM, IWModelClient {
    
    /**
     * The combo box displays the long value of each domain entry.
     */
    public static final int SHOW_LONG = 1;

    /**
     * The combo box displays short and long value of each entry, 
     * separated by dash.
     */
    public static final int SHOW_SHORT_LONG = 2;
    
    /**
     * The combo box displays just the short value of each entry.
     */
    public static final int SHOW_SHORT = 64;

    /**
     * The sort order of the combo box entries follows the lexical
     * order of the short value. This is the default order
     * style for <tt>SHOW_SHORT_LONG</tt>.
     */
    public static final int ORDER_SHORT = 4;

    /**
     * The sort order of the combo box entries is drawn from the
     * lexical order of the long value. This is the default value
     * for <tt>SHOW_LONG</tt>.
     */
    public static final int ORDER_LONG = 8;

    /**
     * The sort order is the natural order of the entries in the
     * data source.
     */
    public static final int ORDER_NATURAL = 16;

    /**
     * Indicates that a value must be provided on the UI
     */
    public static final int MANDATORY = 32;

    /**
     * Returns one of the SHOW_* constants. 
     */
    public abstract int getOrderStyle();
    
    /**
     * Returns one of the ORDER_* constants.
     */
    public abstract int getShowStyle();
    
    /**
     * Returns true if the MANDATORY style has been set at construction time 
     */
    public abstract boolean isMandatory();
    
    /**
     * Sets the mandatory-property.
     * 
     * @param what the new value of the mandatory-value
     */
    public abstract void setMandatory (boolean what);
    
    /**
     * Changes the behaviour of the combo box to show the long values of the 
     * selected value as tooltips, instead of the value entered in the UI-designer.
     */
    public void setShowLongValueToolTips ();
}
