/*******************************************************************************
 * Copyright (c) 2003, 2007 s IT Solutions AT Spardat GmbH .
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     s IT Solutions AT Spardat GmbH - initial API and implementation
 *******************************************************************************/

/*
 * @(#) $Id: HashFilterTest.java 2593 2008-05-23 08:39:25Z gub $
 *
 *
 *
 *
 *
 */
package at.spardat.xma.test;

import at.spardat.xma.boot.cache.VersionNumber;
import at.spardat.xma.session.HashFilter;
import junit.framework.TestCase;
import junit.framework.Assert;

/**
 * @author s2877
 * @since version_number
 */
public class HashFilterTest extends TestCase {

    /**
     * @param arg0
     */
    public HashFilterTest(String arg0) {
        super(arg0);
     }

    public static void main(String[] args) {
        junit.awtui.TestRunner.run(HashFilterTest.class);
    }

    public void testFilterHash() {
        HashFilter filter = new HashFilter();
        String erg;
        erg = filter.filterHash("test1");
        Assert.assertEquals("test1",erg);
        erg = filter.filterHash("nixda.5021a90d1488985cdc37a13a8ea3f8db");
        Assert.assertEquals("nixda",erg);
        erg = filter.filterHash("864ea63d1c5b5d7dfef7e32ba8778a73"); // kein punkt
        Assert.assertEquals("864ea63d1c5b5d7dfef7e32ba8778a73",erg);
        erg = filter.filterHash(".864ea63d1c5b5d7dfef7e32ba8778a73");
        Assert.assertEquals("",erg);
        erg = filter.filterHash("xmartclient_1.4.0.e5150d4822dd4415ed8a254c2bb84695.jar");
        Assert.assertEquals("xmartclient_1.4.0.jar",erg);
        erg = filter.filterHash("xmartclient_1.4.0.1.e5150d4822dd4415ed8a254c2bb84695.jar");
        Assert.assertEquals("xmartclient_1.4.0.1.jar",erg); // four dots
        erg = filter.filterHash("http://localhost:8080/xma_samplespar/clientrt/xmartclient_1.4.0.e5150d4822dd4415ed8a254c2bb84695.jar");
        Assert.assertEquals("http://localhost:8080/xma_samplespar/clientrt/xmartclient_1.4.0.jar",erg);
        erg = filter.filterHash("nixda5021a90d1488985cdc37a13a8ea3f8db");
        Assert.assertEquals("nixda5021a90d1488985cdc37a13a8ea3f8db",erg);
        erg = filter.filterHash("nix.5021a90d1488985cdc37a13a8ea3f8db.da");
        Assert.assertEquals("nix.da",erg);
        erg = filter.filterHash("nix.5021a90d1488985cdc37a13a8ea3f8dbda"); // zu lang
        Assert.assertEquals("nix.5021a90d1488985cdc37a13a8ea3f8dbda",erg);
        erg = filter.filterHash("nix.5021a90d1488985cdc37a13a8ea3"); // zu kurz
        Assert.assertEquals("nix.5021a90d1488985cdc37a13a8ea3",erg);
        erg = filter.filterHash("nix.5021a90d1488985cdX37a13a8ea3f8db"); // falsches Zeichen X
        Assert.assertEquals("nix.5021a90d1488985cdX37a13a8ea3f8db",erg);

        //compatibility tests with insertHash
        String name = VersionNumber.insertHash("/irgendow/versteckt/cache/subdir/clientrt_1.4.0.jar","e5150d4822dd4415ed8a254c2bb84695");
        erg = filter.filterHash(name);
        Assert.assertEquals("/irgendow/versteckt/cache/subdir/clientrt_1.4.0.jar",erg);
        name = VersionNumber.insertHash("c:\\tmp\\clientrt.jar","e5150d4822dd4415ed8a254c2bb84695");
        erg = filter.filterHash(name);
        Assert.assertEquals("c:\\tmp\\clientrt.jar",erg);
        name = VersionNumber.insertHash("itext-1.4.jar","e5150d4822dd4415ed8a254c2bb84695");
        erg = filter.filterHash(name);
        Assert.assertEquals("itext-1.4.jar",erg);
        name = VersionNumber.insertHash("bin/core","e5150d4822dd4415ed8a254c2bb84695");
        erg = filter.filterHash(name);
        Assert.assertEquals("bin/core",erg);
    }


}
